function epsilon = calcEpsilon(Template, Atilde, ttilde, A, t)
% CALCEPSILON computes the epsilon error measure between the estimated
%   affine transformation and the correct one, denoted by (Atilde, ttilde)
%   and (A, t), respectively.
%
%  Author : Csaba Domokos (c.domokos.res@gmail.com)
%           https://sites.google.com/site/cdomokosres/
%  Date   : 25.10.2014
%           12.12.2008
assert(ndims(Template) == 2, 'Template image must be a single channel image')

assert(all(size(Atilde) == [2 2]), 'Atilde must be a 2 x 2 matrix')
assert(all(size(ttilde) == [2 1]), 'tilde must be a 2 x 1 vector')
assert(all(size(A) == [2 2]), 'A must be a 2 x 2 matrix')
assert(all(size(t) == [2 1]), 't must be a 2 x 1 vector')

[y x] = find(Template);
epsilon = mean(sqrt(sum(bsxfun(@plus, (A - Atilde) * [x y]', t - ttilde) .^ 2)));