clear all, clc

% select the Template and Observation images
templateDir = '../affineShapeAlignmentDataset/Templates/';
observationDir = '../affineShapeAlignmentDataset/Observations/';

templateFilename = 'image0005.png';
observationFilename = 'observation0005_0015.png';
dataFilename = [observationDir observationFilename(1 : strfind(observationFilename, '.png')) 'dat'];

% load the input images
Template = bwlabel(imread([templateDir templateFilename]));
Observation = bwlabel(imread([observationDir observationFilename]));

% registration
rtime = cputime;
[Atilde ttilde] = affineCompoundShapeAlignment(Template, Observation);
disp(['Elapsed time: ' num2str(cputime - rtime) ' sec.'])

% load the correct transformation parameters from file
% (Note that this is required to calculate epsilon error measure)
fp = fopen(dataFilename, 'r');
for i = 1 : 2, fgetl(fp); end
%A = zeros(2);
%t = zeros(2, 1);
A(1, 1) = line2double(fgetl(fp), '=');
A(1, 2) = line2double(fgetl(fp), '=');
t(1, 1) = line2double(fgetl(fp), '=');
A(2, 1) = line2double(fgetl(fp), '=');
A(2, 2) = line2double(fgetl(fp), '=');
t(2, 1) = line2double(fgetl(fp), '=');
fclose(fp);

% evaluate the error measures
[delta diffImg] = calcDelta(Template, Observation, Atilde, ttilde);
epsilon = calcEpsilon(Template, Atilde, ttilde, A, t);
disp(['Error measures: delta = ' num2str(delta, '%.2f') ', epsilon = ' num2str(epsilon, '%.2f')])

% show the result
subplot(1, 3, 1), imshow(Template), title('Template')
subplot(1, 3, 2), imshow(Observation), title('Observation')
subplot(1, 3, 3), imshow(diffImg), title('Abolsute difference')